@@ -13,28 +13,23 @@ from functools import wraps
 
 import gevent
 
-from behave.runner import Context
-from behave.model import Status
-from locust.runners import MasterRunner, WorkerRunner, Runner
-from locust.env import Environment
-from locust import stats as lstats
+from locust import stats as lstats, events
 from locust.log import setup_logging
 from locust.util.timespan import parse_timespan
-from locust import events
+from locust.user.users import User
 from jinja2.exceptions import TemplateError
 
-from grizzly.types import RequestType, TestdataType
-
 from . import __version__, __locust_version__
 from .listeners import init, init_statistics_listener, quitting, validate_result, spawning_complete, locust_test_start, locust_test_stop
 from .testdata.utils import initialize_testdata
 from .context import GrizzlyContext
 from .tasks import GrizzlyTask
-from .users.base import GrizzlyUser
-
 from .utils import create_scenario_class_type, create_user_class_type
+from .types import RequestType, TestdataType
+from .types.locust import Environment, LocustRunner, MasterRunner, WorkerRunner, MessageHandler
+from .types.behave import Context, Status
 
-__all__: List[str] = [
+__all__ = [
     'stats_logger',
 ]
 
@@ -80,8 +75,8 @@ def on_local(context: Context) -> bool:
     return value
 
 
-def setup_locust_scenarios(grizzly: GrizzlyContext) -> Tuple[List[Type[GrizzlyUser]], List[GrizzlyTask], Set[str]]:
-    user_classes: List[Type[GrizzlyUser]] = []
+def setup_locust_scenarios(grizzly: GrizzlyContext) -> Tuple[List[Type[User]], List[GrizzlyTask], Set[str]]:
+    user_classes: List[Type[User]] = []
     tasks: List[GrizzlyTask] = []
 
     scenarios = grizzly.scenarios()
@@ -89,7 +84,6 @@ def setup_locust_scenarios(grizzly: GrizzlyContext) -> Tuple[List[Type[GrizzlyUs
     assert len(scenarios) > 0, 'no scenarios in feature'
 
     external_dependencies: Set[str] = set()
-    dummy_environment = Environment()
     distribution: Dict[str, int] = {}
 
     total_weight = sum([scenario.user.weight for scenario in scenarios])
@@ -125,9 +119,6 @@ def setup_locust_scenarios(grizzly: GrizzlyContext) -> Tuple[List[Type[GrizzlyUs
         user_class_type = create_user_class_type(scenario, grizzly.setup.global_context, fixed_count=fixed_count)
         user_class_type.host = scenario.context['host']
 
-        # fail early if there is a problem with creating an instance of the user class
-        user_class_type(dummy_environment)
-
         external_dependencies.update(user_class_type.__dependencies__)
 
         # @TODO: how do we specify other type of grizzly.scenarios?
@@ -153,7 +144,7 @@ def setup_locust_scenarios(grizzly: GrizzlyContext) -> Tuple[List[Type[GrizzlyUs
 
 
 def setup_resource_limits(context: Context) -> None:
-    if sys.platform != 'win32' and on_master(context):
+    if sys.platform != 'win32' and not on_master(context):
         try:
             import resource
             minimum_open_file_limit = 10000
@@ -171,7 +162,7 @@ def setup_resource_limits(context: Context) -> None:
             )
 
 
-def setup_environment_listeners(context: Context, tasks: List[GrizzlyTask]) -> Set[str]:
+def setup_environment_listeners(context: Context, tasks: List[GrizzlyTask]) -> Tuple[Set[str], Dict[str, MessageHandler]]:
     grizzly = cast(GrizzlyContext, context.grizzly)
 
     environment = grizzly.state.locust.environment
@@ -185,10 +176,11 @@ def setup_environment_listeners(context: Context, tasks: List[GrizzlyTask]) -> S
     # add standard listeners
     testdata: Optional[TestdataType] = None
     external_dependencies: Set[str] = set()
+    message_handlers: Dict[str, MessageHandler] = {}
 
     # initialize testdata
     try:
-        testdata, external_dependencies = initialize_testdata(grizzly, tasks)
+        testdata, external_dependencies, message_handlers = initialize_testdata(grizzly, tasks)
     except TemplateError as e:
         logger.error(e, exc_info=True)
         raise AssertionError(f'error parsing request payload: {e}') from e
@@ -220,7 +212,7 @@ def setup_environment_listeners(context: Context, tasks: List[GrizzlyTask]) -> S
     if grizzly.setup.statistics_url is not None:
         environment.events.init.add_listener(init_statistics_listener(grizzly.setup.statistics_url))
 
-    return external_dependencies
+    return external_dependencies, message_handlers
 
 
 def print_scenario_summary(grizzly: GrizzlyContext) -> None:
@@ -354,7 +346,7 @@ def run(context: Context) -> int:
             stop_timeout=300,  # only wait at most?
         )
 
-        runner: Runner
+        runner: LocustRunner
 
         if on_master(context):
             host = '0.0.0.0'
@@ -382,7 +374,7 @@ def run(context: Context) -> int:
 
         grizzly.state.locust = runner
 
-        variable_dependencies = setup_environment_listeners(context, tasks)
+        variable_dependencies, message_handlers = setup_environment_listeners(context, tasks)
         external_dependencies.update(variable_dependencies)
 
         environment.events.init.fire(environment=environment, runner=runner, web_ui=None)
@@ -430,6 +422,11 @@ def run(context: Context) -> int:
             watch_running_external_processes_greenlet = gevent.spawn_later(10, start_watching_external_processes(external_processes))
             watch_running_external_processes_greenlet.link_exception(greenlet_exception_handler)
 
+        if not on_worker(context) and len(message_handlers) > 0:
+            for message_type, callback in message_handlers.items():
+                grizzly.state.locust.register_message(message_type, callback)
+                logger.info(f'registered callback for message type "{message_type}"')
+
         main_greenlet = runner.greenlet
 
         # And run for maximum
