@@ -30,6 +30,8 @@ class IteratorScenario(GrizzlyScenario):
     behave_steps: Dict[int, str]
     pace_time: Optional[str] = None  # class variable injected by `grizzly.utils.create_scenario_class_type`
 
+    _prefetch: bool
+
     current_task_index: int = 0
 
     def __init__(self, parent: 'GrizzlyUser') -> None:
@@ -39,6 +41,7 @@ class IteratorScenario(GrizzlyScenario):
         self.task_count = len(self.tasks)
         self.stats = self.user.environment.stats.get(self.user._scenario.locust_name, RequestType.SCENARIO())
         self.behave_steps = self.user._scenario.tasks.behave_steps.copy()
+        self._prefetch = False
 
     def run(self) -> None:  # type: ignore
         try:
@@ -48,6 +51,8 @@ class IteratorScenario(GrizzlyScenario):
                 raise RescheduleTaskImmediately(e.reschedule).with_traceback(e.__traceback__)
             else:
                 raise RescheduleTask(e.reschedule).with_traceback(e.__traceback__)
+        except StopScenario as e:
+            raise StopUser() from e
 
         while True:
             try:
@@ -64,6 +69,7 @@ class IteratorScenario(GrizzlyScenario):
                         step = self.behave_steps.get(self.current_task_index + 1, self._task_queue[0].__name__)
                     except Exception:
                         step = 'unknown'
+
                     self.logger.debug(f'executing task {self.current_task_index+1} of {self.task_count}: {step}')
                     self.execute_next_task()
                 except RescheduleTaskImmediately:
@@ -82,7 +88,10 @@ class IteratorScenario(GrizzlyScenario):
                     self.wait()
             except InterruptTaskSet as e:
                 if self.user._scenario_state != ScenarioState.STOPPING:
-                    self.on_stop()
+                    try:
+                        self.on_stop()
+                    except:
+                        self.logger.error('on_stop failed', exc_info=True)
                     self.start = None
 
                     if e.reschedule:
@@ -106,7 +115,10 @@ class IteratorScenario(GrizzlyScenario):
                         e = StopUser()
 
                     self.iteration_stop(has_error=has_error)
-                    self.on_stop()
+                    try:
+                        self.on_stop()
+                    except:
+                        self.logger.error('on_stop failed', exc_info=True)
 
                     raise e
                 else:
@@ -144,8 +156,17 @@ class IteratorScenario(GrizzlyScenario):
 
         super().wait()
 
+    def prefetch(self) -> None:
+        self.iterator(prefetch=True)
+
     @task
-    def iterator(self) -> None:
+    def iterator(self, prefetch: Optional[bool] = False) -> None:
+        # if data has been prefetched, use it for the first iteration,
+        # then ask for new data the second iteration
+        if self._prefetch:
+            self._prefetch = False
+            return
+
         if self.start is not None:
             response_time = int((perf_counter() - self.start) * 1000)
             self.user.environment.events.request.fire(
@@ -179,7 +200,11 @@ class IteratorScenario(GrizzlyScenario):
 
         self.user.add_context(remote_context)
 
-    # user tasks will be injected between these two
+        # next call to this method should be ignored, first iteration should use the prefetched data
+        if prefetch:
+            self._prefetch = True
+
+    # <!-- user tasks will be injected between these two static tasks -->
 
     @task
     def pace(self) -> None:
