@@ -35,12 +35,13 @@ from time import perf_counter
 
 from gevent import sleep as gsleep
 
-if TYPE_CHECKING:  # pragma: no cover
-    from ..scenarios import GrizzlyScenario
-    from ..context import GrizzlyContextScenario
+from grizzly.exceptions import StopUser, RestartScenario
 
-from . import GrizzlyTask, GrizzlyTaskWrapper, template
-from ..exceptions import StopUser, RestartScenario
+from . import GrizzlyTask, GrizzlyTaskWrapper, template, grizzlytask
+
+if TYPE_CHECKING:  # pragma: no cover
+    from grizzly.scenarios import GrizzlyScenario
+    from grizzly.context import GrizzlyContextScenario
 
 
 @template('condition', 'tasks', 'name')
@@ -85,12 +86,13 @@ class ConditionalTask(GrizzlyTaskWrapper):
 
         return []
 
-    def __call__(self) -> Callable[['GrizzlyScenario'], Any]:
+    def __call__(self) -> grizzlytask:
         tasks: Dict[bool, List[Callable[['GrizzlyScenario'], Any]]] = {}
 
         for pointer, pointer_tasks in self.tasks.items():
             tasks.update({pointer: list(map(lambda t: t(), pointer_tasks))})
 
+        @grizzlytask
         def task(parent: 'GrizzlyScenario') -> Any:
             condition_rendered = parent.render(self.condition)
             exception: Optional[Exception] = None
