@@ -165,10 +165,6 @@ class AtomicDirectoryContents(AtomicVariable[str]):
             except (IndexError, ValueError):
                 return None
 
-    # not possible to override already initialized variable
-    def __setitem__(self, variable: str, value: Optional[str]) -> None:
-        pass
-
     def __delitem__(self, variable: str) -> None:
         with self.semaphore():
             try:
