@@ -34,14 +34,13 @@ from urllib.parse import urlparse, parse_qs
 from time import perf_counter as time
 
 from azure.storage.blob import BlobServiceClient
-from locust.exception import StopUser
-from locust.env import Environment
 
 from grizzly.types import RequestMethod, GrizzlyResponse, RequestType
+from grizzly.types.locust import Environment, StopUser
+from grizzly.tasks import RequestTask
+from grizzly.utils import merge_dicts
 
 from .base import GrizzlyUser
-from ..tasks import RequestTask
-from ..utils import merge_dicts
 
 
 class BlobStorageUser(GrizzlyUser):
@@ -74,9 +73,16 @@ class BlobStorageUser(GrizzlyUser):
         if 'AccountKey' not in params:
             raise ValueError(f'{self.__class__.__name__} needs AccountKey in the query string')
 
-        self.client = BlobServiceClient.from_connection_string(conn_str=self.host)
         self._context = merge_dicts(super().context(), self.__class__._context)
 
+    def on_start(self) -> None:
+        super().on_start()
+        self.client = BlobServiceClient.from_connection_string(conn_str=self.host)
+
+    def on_stop(self) -> None:
+        self.client.close()
+        super().on_stop()
+
     def request(self, request: RequestTask) -> GrizzlyResponse:
         request_name, endpoint, payload, _, _ = self.render(request)
 
